<template>
    <div>
        <v-container class="grey lighten-5 mb-6">
            <v-row style="height: 170px;">
                <v-col cols="3">
                    <v-card class="mx-auto" max-width="344">
                        <v-img src="https://cdn.vuetifyjs.com/images/cards/house.jpg" height="150px"></v-img>
                        <v-overlay absolute :opacity="0.8" align="center">
                            <v-card-actions>
                                <v-btn @click="$go($route('book.index'))" class="ml-2 mt-1" outlined rounded small>
                                    Books
                                </v-btn>
                            </v-card-actions>
                            {{ data.book }}
                        </v-overlay>
                    </v-card>
                </v-col>
                <v-col cols="3">
                    <v-card class="mx-auto" max-width="344">
                        <v-img
                            src="https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcSFk1nEpvu80Wz4nbUAYXtQuufY1QedJiIA_A&usqp=CAU"
                            height="150px"></v-img>
                        <v-overlay absolute :opacity="0.8" align="center">
                            <v-card-actions>
                                <v-btn @click="$go($route('author.index'))" class="ml-2 mt-1" outlined rounded small>
                                    Authors
                                </v-btn>
                            </v-card-actions>
                            {{ data.author }}
                        </v-overlay>
                    </v-card>
                </v-col>
                <v-col cols="3">
                    <v-card class="mx-auto" max-width="344">
                        <v-img
                            src="https://media.istockphoto.com/id/1368965646/photo/multi-ethnic-guys-and-girls-taking-selfie-outdoors-with-backlight-happy-life-style-friendship.jpg?b=1&s=170667a&w=0&k=20&c=oFtP564Ykvak2VIyM1OUb29daY5S4uqsmT3j3_8QgfQ="
                            height="150px"></v-img>
                        <v-overlay absolute :opacity="0.8" align="center">
                            <v-card-actions>
                                <v-btn @click="$go($route('publisher.index'))" class="ml-2 mt-1" outlined rounded small>
                                    Publishers
                                </v-btn>
                            </v-card-actions>
                            {{ data.publisher }}
                        </v-overlay>
                    </v-card>
                </v-col>
                <v-col cols="3">
                    <v-card class="mx-auto" max-width="344">
                        <v-img
                            src="https://cdn.shopify.com/s/files/1/0903/2160/products/south-beach-leather-journal_1024x1024.jpg?v=1677595269"
                            height="150px"></v-img>
                        <v-overlay absolute :opacity="0.8" align="center">
                            <v-card-actions>
                                <v-btn @click="$go($route('order.index'))" class="ml-2 mt-1" outlined rounded small>
                                    Orders
                                </v-btn>
                            </v-card-actions>
                            {{ data.order }}
                        </v-overlay>
                    </v-card>
                </v-col>
            </v-row>

            <v-row style="height: 130px;">
                <v-col>
                    <v-card class="pa-2" elevation="2" align="center">
                        <v-card-title class="justify-center blue--text">$43,300</v-card-title>
                        <v-card-text>Income</v-card-text>
                    </v-card>
                </v-col>
                <v-col>
                    <v-card class="pa-2" elevation="2" align="center">
                        <v-card-title class="justify-center pink--text">$38,060</v-card-title>
                        <v-card-text>Expenses</v-card-text>
                    </v-card>
                </v-col>
                <v-col>
                    <v-card class="pa-2" elevation="2" align="center">
                        <v-card-title class="justify-center green--text">$5,240</v-card-title>
                        <v-card-text>Balance</v-card-text>
                    </v-card>
                </v-col>
                <v-col>
                    <v-card class="pa-2" elevation="2" align="center">
                        <v-card-title class="justify-center orange--text">$1,284</v-card-title>
                        <v-card-text>Transactions</v-card-text>
                    </v-card>
                </v-col>
            </v-row>

            <v-row style="height: 170px;">
                <v-col cols="4">
                    <!-- pie chart -->
                    <D3PieChart
                        :config="piechart_config"
                        :datum="piechart_data"
                    ></D3PieChart>
                </v-col>
                <v-col cols="4">
                    <!-- bar chart -->
                    <D3BarChart class="mr-5"
                                :config="barchart_config"
                                :datum="barchart_data"
                                :title="barchart_title"
                                :source="barchart_source"
                    ></D3BarChart>
                </v-col>
                <v-col cols="4">
                    <!-- Line chart -->
                    <D3LineChart
                        :config="linechart_config"
                        :datum="linechart_data"
                    ></D3LineChart>
                </v-col>

            </v-row>

        </v-container>
    </div>
</template>

<script>

import {D3PieChart, D3BarChart, D3LineChart} from 'vue-d3-charts';

export default {
    name: "Dashboard",
    components: {D3BarChart, D3PieChart, D3LineChart},
    data() {
        return {
            overlay: true,
            data: this.$page.props.data,
            piechart_data: [
                {hours: 20, name: 'Lorem'},
                {hours: 30, name: 'Ipsum'},
                {hours: 31, name: 'Dolor'},
                {hours: 15, name: 'Sit'},
            ],
            piechart_config: {
                key: 'name',
                value: 'hours',
                color: {scheme: 'schemeTableau10'},
                radius: {inner: false}
            },
            barchart_title: 'Your title goes here',
            barchart_source: 'Your source goes here',
            barchart_data: [
                {hours: 1648, production: 9613, year: '2007'},
                {hours: 2479, production: 6315, year: '2008'},
                {hours: 3200, production: 2541, year: '2009'}
            ],
            barchart_config: {
                key: 'year',
                currentKey: '2004',
                values: ['hours'],
                axis: {
                    yTicks: 3
                },
                color: {
                    default: '#222f3e',
                    current: '#41B882'
                }
            },
            linechart_data: [
                {hours: 2092, production: 1343, date: 2003},
                {hours: 2847, production: 1346, date: 2004},
                {hours: 2576, production: 1233, date: 2005},
                {hours: 2524, production: 1325, date: 2006},
                {hours: 1648, production: 1456, date: 2007}
            ],
            linechart_config: {
                values: ['hours', 'production'],
                date: {
                    key: 'date',
                    inputFormat: '%Y',
                    outputFormat: '%Y',
                },
                tooltip: {
                    labels: ['Total hours', 'Total production']
                },
                axis: {
                    yFormat: '.1s',
                    yTicks: 6,
                    yTitle: 'Lorem ipsum',
                    xTicks: 5,
                },
                color: {
                    scheme: ['#41B882', '#222f3e']
                },
                curve: 'curveStep',
                transition: {
                    ease: 'easeBounceOut',
                    duration: 1000
                }
            }

        }
    },
    methods: {
    },
    mounted() {
    }
}
</script>

<style scoped>

</style>
